@@ -50,7 +50,7 @@ class DataModelFieldBase(_BaseModel):
     _pass_fields: ClassVar[Set[str]] = {'parent', 'data_type'}
 
     def __init__(self, **data: Any):  # type: ignore
-        super().__init__(**data)  # type: ignore
+        super().__init__(**data)
         if isinstance(self.data_type, DataType) and self.data_type.reference:
             self.data_type.parent = self
 
@@ -137,7 +137,7 @@ class TemplateBase(ABC):
         return self.render()
 
 
-class BaseClassDataType(DataType):
+class BaseClassDataType(DataType):  # type: ignore
     ...
 
 
@@ -223,7 +223,8 @@ class DataModel(TemplateBase, ABC):
     @property
     def imports(self) -> Tuple[Import, ...]:
         return chain_as_tuple(
-            (i for f in self.fields for i in f.imports), self._additional_imports,
+            (i for f in self.fields for i in f.imports),
+            self._additional_imports,
         )
 
     @property
