@@ -1,6 +1,7 @@
 import enum as _enum
 from collections import defaultdict
 from contextlib import contextmanager
+from functools import lru_cache
 from pathlib import Path
 from typing import (
     Any,
@@ -41,7 +42,7 @@ from datamodel_code_generator.parser.base import (
     escape_characters,
     title_to_class_name,
 )
-from datamodel_code_generator.reference import Reference, is_url
+from datamodel_code_generator.reference import ModelType, Reference, is_url
 from datamodel_code_generator.types import DataType, DataTypeManager, StrictTypes, Types
 
 
@@ -236,14 +237,19 @@ class JsonSchemaObject(BaseModel):
     @cached_property
     def ref_type(self) -> Optional[JSONReference]:
         if self.ref:
-            if self.ref[0] == '#':
-                return JSONReference.LOCAL
-            elif is_url(self.ref):
-                return JSONReference.URL
-            return JSONReference.REMOTE
+            return get_ref_type(self.ref)
         return None  # pragma: no cover
 
 
+@lru_cache()
+def get_ref_type(ref: str) -> JSONReference:
+    if ref[0] == '#':
+        return JSONReference.LOCAL
+    elif is_url(ref):
+        return JSONReference.URL
+    return JSONReference.REMOTE
+
+
 JsonSchemaObject.update_forward_refs()
 
 DEFAULT_FIELD_KEYS: Set[str] = {
@@ -300,6 +306,7 @@ class JsonSchemaParser(Parser):
         custom_class_name_generator: Optional[Callable[[str], str]] = None,
         field_extra_keys: Optional[Set[str]] = None,
         field_include_all_keys: bool = False,
+        wrap_string_literal: Optional[bool] = None,
     ):
         super().__init__(
             source=source,
@@ -338,6 +345,7 @@ class JsonSchemaParser(Parser):
             custom_class_name_generator=custom_class_name_generator,
             field_extra_keys=field_extra_keys,
             field_include_all_keys=field_include_all_keys,
+            wrap_string_literal=wrap_string_literal,
         )
 
         self.remote_object_cache: DefaultPutDict[str, Dict[str, Any]] = DefaultPutDict()
@@ -388,7 +396,8 @@ class JsonSchemaParser(Parser):
                 )
                 data_formats = json_schema_data_formats[type_]['default']
             return self.data_type_manager.get_data_type(
-                data_formats, **obj.dict() if not self.field_constraints else {},
+                data_formats,
+                **obj.dict() if not self.field_constraints else {},
             )
 
         if isinstance(obj.type, list):
@@ -405,7 +414,7 @@ class JsonSchemaParser(Parser):
         return self.data_type(reference=reference)
 
     def set_additional_properties(self, name: str, obj: JsonSchemaObject) -> None:
-        if obj.additionalProperties:
+        if obj.additionalProperties is not None:
             # TODO check additional property types.
             self.extra_template_data[name][
                 'additionalProperties'
@@ -447,7 +456,9 @@ class JsonSchemaParser(Parser):
             else:
                 fields.extend(
                     self.parse_object_fields(
-                        all_of_item, path, get_module_name(name, None),
+                        all_of_item,
+                        path,
+                        get_module_name(name, None),
                     )
                 )
         if obj.properties:
@@ -547,7 +558,11 @@ class JsonSchemaParser(Parser):
                 f'This argument will be removed in a future version'
             )
         reference = self.model_resolver.add(
-            path, name, class_name=True, singular_name=singular_name, loaded=True,
+            path,
+            name,
+            class_name=True,
+            singular_name=singular_name,
+            loaded=True,
         )
         class_name = reference.name
         self.set_title(class_name, obj)
@@ -582,7 +597,10 @@ class JsonSchemaParser(Parser):
             root_type_path = get_special_path('array', path)
             return self.parse_root_type(
                 self.model_resolver.add(
-                    root_type_path, name, class_name=True, singular_name=singular_name,
+                    root_type_path,
+                    name,
+                    class_name=True,
+                    singular_name=singular_name,
                 ).name,
                 item,
                 root_type_path,
@@ -650,16 +668,25 @@ class JsonSchemaParser(Parser):
         target_items: List[JsonSchemaObject],
         path: List[str],
         parent: JsonSchemaObject,
+        singular_name: bool = True,
     ) -> List[DataType]:
         return [
             self.parse_item(
-                name, item, [*path, str(index)], singular_name=True, parent=parent
+                name,
+                item,
+                [*path, str(index)],
+                singular_name=singular_name,
+                parent=parent,
             )
             for index, item in enumerate(target_items)
         ]
 
     def parse_array_fields(
-        self, name: str, obj: JsonSchemaObject, path: List[str]
+        self,
+        name: str,
+        obj: JsonSchemaObject,
+        path: List[str],
+        singular_name: bool = True,
     ) -> DataModelFieldBase:
         if self.force_optional_for_required_fields:
             required: bool = False
@@ -683,6 +710,7 @@ class JsonSchemaParser(Parser):
                     else obj.items or [],
                     path,
                     obj,
+                    singular_name=singular_name,
                 ),
                 is_list=True,
             )
@@ -755,7 +783,10 @@ class JsonSchemaParser(Parser):
         return self.data_type(reference=reference)
 
     def parse_root_type(
-        self, name: str, obj: JsonSchemaObject, path: List[str],
+        self,
+        name: str,
+        obj: JsonSchemaObject,
+        path: List[str],
     ) -> DataType:
         if obj.ref:
             data_type: DataType = self.get_ref_data_type(obj.ref)
@@ -866,8 +897,8 @@ class JsonSchemaParser(Parser):
                         else type(enum_part).__name__
                     )
                     field_name = f'{prefix}_{enum_part}'
-            field_name = self.model_resolver.get_valid_name(
-                field_name, excludes=exclude_field_names
+            field_name = self.model_resolver.get_valid_field_name(
+                field_name, excludes=exclude_field_names, model_type=ModelType.ENUM
             )
             exclude_field_names.add(field_name)
             enum_fields.append(
@@ -953,40 +984,47 @@ class JsonSchemaParser(Parser):
             default_factory=lambda _: load_yaml_from_path(full_path, self.encoding),
         )
 
+    def resolve_ref(self, object_ref: str) -> Reference:
+        reference = self.model_resolver.add_ref(object_ref)
+        if reference.loaded:
+            return reference
+
+        # https://swagger.io/docs/specification/using-ref/
+        ref = self.model_resolver.resolve_ref(object_ref)
+        if get_ref_type(object_ref) == JSONReference.LOCAL:
+            # Local Reference – $ref: '#/definitions/myElement'
+            self.reserved_refs[tuple(self.model_resolver.current_root)].add(ref)  # type: ignore
+            return reference
+        elif self.model_resolver.is_after_load(ref):
+            self.reserved_refs[tuple(ref.split('#')[0].split('/'))].add(ref)  # type: ignore
+            return reference
+
+        if is_url(ref):
+            relative_path, object_path = ref.split('#')
+            relative_paths = [relative_path]
+            base_path = None
+        else:
+            if self.model_resolver.is_external_root_ref(ref):
+                relative_path, object_path = ref[:-1], ''
+            else:
+                relative_path, object_path = ref.split('#')
+            relative_paths = relative_path.split('/')
+            base_path = Path(*relative_paths).parent
+        with self.model_resolver.current_base_path_context(
+            base_path
+        ), self.model_resolver.base_url_context(relative_path):
+            self._parse_file(
+                self._get_ref_body(relative_path),
+                self.model_resolver.add_ref(ref, resolved=True).name,
+                relative_paths,
+                object_path.split('/') if object_path else None,
+            )
+        reference.loaded = True
+        return reference
+
     def parse_ref(self, obj: JsonSchemaObject, path: List[str]) -> None:
         if obj.ref:
-            reference = self.model_resolver.add_ref(obj.ref)
-            if not reference or not reference.loaded:
-                # https://swagger.io/docs/specification/using-ref/
-                ref = self.model_resolver.resolve_ref(obj.ref)
-                if obj.ref_type == JSONReference.LOCAL:
-                    # Local Reference – $ref: '#/definitions/myElement'
-                    self.reserved_refs[tuple(self.model_resolver.current_root)].add(ref)  # type: ignore
-                elif self.model_resolver.is_after_load(ref):
-                    self.reserved_refs[tuple(ref.split('#')[0].split('/'))].add(ref)  # type: ignore
-                else:
-                    if is_url(ref):
-                        relative_path, object_path = ref.split('#')
-                        relative_paths = [relative_path]
-                        base_path = None
-                    else:
-                        if self.model_resolver.is_external_root_ref(ref):
-                            relative_path, object_path = ref[:-1], ''
-                        else:
-                            relative_path, object_path = ref.split('#')
-                        relative_paths = relative_path.split('/')
-                        base_path = Path(*relative_paths).parent
-                    with self.model_resolver.current_base_path_context(
-                        base_path
-                    ), self.model_resolver.base_url_context(relative_path):
-                        self._parse_file(
-                            self._get_ref_body(relative_path),
-                            self.model_resolver.add_ref(ref, resolved=True).name,
-                            relative_paths,
-                            object_path.split('/') if object_path else None,
-                        )
-                    self.model_resolver.add_ref(obj.ref,).loaded = True
-
+            self.resolve_ref(obj.ref)
         if obj.items:
             if isinstance(obj.items, JsonSchemaObject):
                 self.parse_ref(obj.items, path)
@@ -1032,10 +1070,20 @@ class JsonSchemaParser(Parser):
         yield
         self.root_id = previous_root_id
 
-    def parse_raw_obj(self, name: str, raw: Dict[str, Any], path: List[str],) -> None:
+    def parse_raw_obj(
+        self,
+        name: str,
+        raw: Dict[str, Any],
+        path: List[str],
+    ) -> None:
         self.parse_obj(name, JsonSchemaObject.parse_obj(raw), path)
 
-    def parse_obj(self, name: str, obj: JsonSchemaObject, path: List[str],) -> None:
+    def parse_obj(
+        self,
+        name: str,
+        obj: JsonSchemaObject,
+        path: List[str],
+    ) -> None:
         if obj.is_array:
             self.parse_array(name, obj, path)
         elif obj.allOf:
